abacusai.document_retriever_lookup_result — AbacusAI documentation

# abacusai.document_retriever_lookup_result

## Classes

`DocumentRetrieverLookupResult` | Result of a document retriever lookup.

## Module Contents

class abacusai.document_retriever_lookup_result.DocumentRetrieverLookupResult(client, document=None, score=None, properties=None, pages=None, boundingBoxes=None, documentSource=None, imageIds=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Result of a document retriever lookup.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - document (str) – The document that was looked up.

    - score (float) – Score of the document with respect to the query.

    - properties (dict) – Properties of the retrieved documents.

    - pages (list) – Pages of the retrieved text from the original document.

    - boundingBoxes (list) – Bounding boxes of the retrieved text from the original document.

    - documentSource (str) – Document source name.

    - imageIds (list) – List of Image IDs for all the pages.

  document
  score
  properties
  pages
  bounding_boxes
  document_source
  image_ids
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict